@@ -209,10 +209,7 @@ class BaseRun(DataMixin, models.Model):
             if self.multiplayer:
                 lobby: Lobby
                 for lobby in self.lobby_set.ready():
-                    instance, created = self.get_or_create_multiplayer_instance(lobby)
-                    player: BasePlayer
-                    for player in lobby.player_set.ready():
-                        self.add_player_to_instance(player, instance)
+                    instance, created = self.create_multiplayer_instance_from_lobby(lobby)
                     if created:
                         instances.append(instance)
             else:
@@ -221,6 +218,14 @@ class BaseRun(DataMixin, models.Model):
                     instances.append(instance)
         return instances
 
+    def create_multiplayer_instance_from_lobby(self, lobby):
+        assert lobby.run == self and lobby.ready
+        instance, created = self.get_or_create_multiplayer_instance(lobby)
+        player: BasePlayer
+        for player in lobby.player_set.ready():
+            self.add_player_to_instance(player, instance)
+        return instance, created
+
     def add_player_to_instance(self, player: BasePlayer, instance: BaseInstance):
         player.character = get_character_model().objects.create(
             instance=instance,
@@ -439,7 +444,7 @@ class BasePlayer(models.Model):
         Lobby, on_delete=models.SET_NULL, blank=True, null=True
     )
     character: Optional[Character] = models.ForeignKey(
-        settings.SIMPL_CHARACTER, on_delete=models.CASCADE, blank=True, null=True
+        settings.SIMPL_CHARACTER, on_delete=models.SET_NULL, blank=True, null=True
     )
     completed = models.DateTimeField(blank=True, null=True)
 
